@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 '''
 test_examples.py - Unit tests for Python-LLFUSE.
 
@@ -9,7 +8,6 @@ This file is part of Python-LLFUSE. This work may be distributed under
 the terms of the GNU LGPL.
 '''
 
-from __future__ import division, print_function, absolute_import
 
 if __name__ == '__main__':
     import pytest
@@ -26,6 +24,7 @@ import filecmp
 import errno
 from tempfile import NamedTemporaryFile
 from util import fuse_test_marker, wait_for_mount, umount, cleanup
+from llfuse import _NANOS_PER_SEC
 
 basename = os.path.join(os.path.dirname(__file__), '..')
 TEST_FILE = __file__
@@ -50,11 +49,11 @@ def test_lltest(tmpdir):
         wait_for_mount(mount_process, mnt_dir)
         assert os.listdir(mnt_dir) == [ 'message' ]
         filename = os.path.join(mnt_dir, 'message')
-        with open(filename, 'r') as fh:
+        with open(filename) as fh:
             assert fh.read() == 'hello world\n'
         with pytest.raises(IOError) as exc_info:
             open(filename, 'r+')
-        assert exc_info.value.errno == errno.EPERM
+        assert exc_info.value.errno == errno.EACCES
         with pytest.raises(IOError) as exc_info:
             open(filename + 'does-not-exist', 'r+')
         assert exc_info.value.errno == errno.ENOENT
@@ -80,6 +79,7 @@ def test_tmpfs(tmpdir):
         tst_chown(mnt_dir)
         tst_chmod(mnt_dir)
         tst_utimens(mnt_dir)
+        tst_rounding(mnt_dir)
         tst_link(mnt_dir)
         tst_readdir(mnt_dir)
         tst_statvfs(mnt_dir)
@@ -92,8 +92,6 @@ def test_tmpfs(tmpdir):
     else:
         umount(mount_process, mnt_dir)
 
-@pytest.mark.skipif(sys.version_info < (3,3),
-                    reason="requires python3.3")
 def test_passthroughfs(tmpdir):
     mnt_dir = str(tmpdir.mkdir('mnt'))
     src_dir = str(tmpdir.mkdir('src'))
@@ -113,6 +111,7 @@ def test_passthroughfs(tmpdir):
         tst_chmod(mnt_dir)
         # Underlying fs may not have full nanosecond resolution
         tst_utimens(mnt_dir, ns_tol=1000)
+        tst_rounding(mnt_dir)
         tst_link(mnt_dir)
         tst_readdir(mnt_dir)
         tst_statvfs(mnt_dir)
@@ -267,11 +266,8 @@ def tst_readdir(mnt_dir):
     os.rmdir(subdir)
     os.rmdir(dir_)
 
-def tst_truncate_path(mnt_dir):
-    if sys.version_info < (3,0):
-        # 2.x has no os.truncate
-        return
 
+def tst_truncate_path(mnt_dir):
     assert len(TEST_DATA) > 1024
 
     filename = os.path.join(mnt_dir, name_generator())
@@ -326,20 +322,45 @@ def tst_utimens(mnt_dir, ns_tol=0):
 
     atime = fstat.st_atime + 42.28
     mtime = fstat.st_mtime - 42.23
-    if sys.version_info < (3,3):
-        os.utime(filename, (atime, mtime))
-    else:
-        atime_ns = fstat.st_atime_ns + int(42.28*1e9)
-        mtime_ns = fstat.st_mtime_ns - int(42.23*1e9)
-        os.utime(filename, None, ns=(atime_ns, mtime_ns))
+    atime_ns = fstat.st_atime_ns + int(42.28*1e9)
+    mtime_ns = fstat.st_mtime_ns - int(42.23*1e9)
+    os.utime(filename, None, ns=(atime_ns, mtime_ns))
 
     fstat = os.lstat(filename)
 
     assert abs(fstat.st_atime - atime) < 1e-3
     assert abs(fstat.st_mtime - mtime) < 1e-3
-    if sys.version_info >= (3,3):
-        assert abs(fstat.st_atime_ns - atime_ns) <= ns_tol
-        assert abs(fstat.st_mtime_ns - mtime_ns) <= ns_tol
+    assert abs(fstat.st_atime_ns - atime_ns) <= ns_tol
+    assert abs(fstat.st_mtime_ns - mtime_ns) <= ns_tol
+
+    checked_unlink(filename, mnt_dir, isdir=True)
+
+def tst_rounding(mnt_dir, ns_tol=0):
+    filename = os.path.join(mnt_dir, name_generator())
+    os.mkdir(filename)
+    fstat = os.lstat(filename)
+
+    # Approximately 100 years
+    secs = 100 * 365 * 24 * 3600 + 999
+    # Max nanos
+    nanos = _NANOS_PER_SEC - 1
+
+    # seconds+ns and ns_tol as a float in seconds 
+    secs_f = secs + nanos / _NANOS_PER_SEC
+    secs_tol = ns_tol / _NANOS_PER_SEC
+    
+    atime_ns = secs * _NANOS_PER_SEC + nanos
+    mtime_ns = atime_ns
+
+    os.utime(filename, None, ns=(atime_ns, mtime_ns))
+
+    fstat = os.lstat(filename)
+
+    assert abs(fstat.st_atime - secs_f) <= secs_tol
+    assert abs(fstat.st_mtime - secs_f) <= secs_tol
+
+    assert abs(fstat.st_atime_ns - atime_ns) <= ns_tol
+    assert abs(fstat.st_mtime_ns - mtime_ns) <= ns_tol
 
     checked_unlink(filename, mnt_dir, isdir=True)
 
